@@ -1,9 +1,10 @@
-from typing import Optional
+from typing import List, Optional
 
 from pydantic import BaseModel
 
 from ..base_model import BaseResponseModel
 
+from .tax import TaxesResponse
 
 class AddOn(BaseModel):
     name: Optional[str]
@@ -11,6 +12,7 @@ class AddOn(BaseModel):
     amount_cents: Optional[int]
     amount_currency: Optional[str]
     description: Optional[str]
+    tax_codes: Optional[List[str]]
 
 
 class AddOnResponse(BaseResponseModel):
@@ -21,3 +23,4 @@ class AddOnResponse(BaseResponseModel):
     amount_currency: str
     created_at: str
     description: Optional[str]
+    taxes: Optional[TaxesResponse]
